source activate protac

 'This script performs minimization on ternary complex structure predictions.
  Following the execution of run.sh, the structure predictions produced can
  be minimized. 

  Prior to running this script the following files are required:
	A zdock/out_filter and confs/ directories containing the output files
	produced by executing run.sh

	conf_output: a list of the predicted ternary complexes (the "gen_conf.out"
			   file produced from run.sh)

	lig_xml: the ligand parameter file. Generated by running the 
		    minimize_lig.py script followed by param_lig.py on the generated
		    PROTAC conformer (e.g. protac_conf_0.pdb file from
		    confs/$conf_num would be used as input for the two scripts).
		    The parameterization process is very time consuming (several
              hours) and therefore is not included in this script.
	
	The zrank binary in the top level directory (or comment out last line)


  Example command:
	./run_min.sh gen_conf.out protac_ligname.xml
 '

conf_output=$1
lig_xml=$2

#Generate working directories and remove ligands from predicted ternary complex
#Move protein complex and PROTAC conformer ligands into generated working 
# directories
mkdir confs_min
cat $conf_output | while read line; do
	d=`echo $line | cut -f2 -d'.'`;
	mkdir confs_min/$d; 
	cp zdock/out_filter/$line  confs_min/$d;
	sed -i '/HETATM/d' confs_min/$d/$line;
	cp confs/$d/protac_conf_0.pdb confs_min/$d;
done

#Run parallel minimization of PROTAC conformer ligands in the working
# directories
for d in confs_min/*; do
	num=`echo $d | cut -f2 -d '/'`;
	echo "source activate protac; python ./py/minimize_lig.py \
-l protac_conf_0.pdb -i $d -o $d" >> command_min_lig.txt;
done

cores=$(fgrep -c processor /proc/cpuinfo)
xargs --arg-file=command_min_lig.txt \
      --max-procs=$cores  \
      --replace \
      --verbose \
      /bin/sh -c "{}"

#Run minimzation of each complex (complex minimzation already is run in
# parallel)
for d in confs_min/*; do
	num=`echo $d | cut -f2 -d '/'`;
	python ./py/minimize_complex.py -l protac_conf_0_opt.pdb -x $lig_xml \
 -p complex.$num.pdb -i $d -o $d;
done

#Generate list of minimized output files and score each with ZRANK
ls confs_min/*/*_min.pdb > conf_min.out
./zrank conf_min.out
